# aicrowd-cli
A CLI app to interact with AIcrowd

[![pipeline status](http://gitlab.aicrowd.com/aicrowd/aicrowd-cli/badges/master/pipeline.svg)](http://gitlab.aicrowd.com/aicrowd/aicrowd-cli/-/commits/master)
[![coverage report](http://gitlab.aicrowd.com/aicrowd/aicrowd-cli/badges/master/coverage.svg)](http://gitlab.aicrowd.com/aicrowd/aicrowd-cli/-/commits/master)

### Supported versions
python3.6 and above
